From eabf3bace72b35364bbb2e5d7a1b59764d929caa Mon Sep 17 00:00:00 2001
From: Jie Fu <jiefu@openjdk.org>
Date: Tue, 17 Nov 2020 01:35:30 +0000
Subject: [PATCH] 8256037: [TESTBUG]
 com/sun/jndi/dns/ConfigTests/PortUnreachable.java fails due to the hard coded
 threshold is small

Reviewed-by: shade, aefimov
---
 test/jdk/com/sun/jndi/dns/ConfigTests/PortUnreachable.java | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/test/jdk/com/sun/jndi/dns/ConfigTests/PortUnreachable.java b/test/jdk/com/sun/jndi/dns/ConfigTests/PortUnreachable.java
index 31732165e72..057b7a02f70 100644
--- a/test/jdk/com/sun/jndi/dns/ConfigTests/PortUnreachable.java
+++ b/test/jdk/com/sun/jndi/dns/ConfigTests/PortUnreachable.java
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2002, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -44,9 +44,9 @@ public class PortUnreachable extends DNSTestBase {
 
     // Threshold in ms for elapsed time of request failed. Normally, it should
     // be very quick, but consider to different platform and test machine
     // performance, here we define 1000 ms as threshold which acceptable for
     // this test.
-    private static final int THRESHOLD = 1000;
+    private static final int THRESHOLD = 3000;
 
     private long startTime;
@@ -44,9 +44,9 @@ public class PortUnreachable extends DNSTestBase {
     // Threshold in ms for elapsed time of request failed. Normally, it should
     // be very quick, but consider to different platform and test machine
-    // performance, here we define 1000 ms as threshold which acceptable for
+    // performance, here we define 3000 ms as threshold which acceptable for
     // this test.